## Built-in plugins
* Amazon Web Services
* Azure Active Directory
* Google Workspace
* Okta

## Community plugins
Be the first to contribute your own plugin.

## Template Type

Template type has to be unique across plugins.

| Template Type | Plugin Shortname | Plugin Namespace |
| ----------- | ----------- |  ----------- |
| NOQ::AWS::IdentityCenter::PermissionSet | Amazon Web Services | iambic.plugins.v0_1_0.aws |
| NOQ::AWS::IAM::Role | Amazon Web Services | iambic.plugins.v0_1_0.aws |
| NOQ::AWS::IAM::ManagedPolicy | Amazon Web Services | iambic.plugins.v0_1_0.aws |
| NOQ::AWS::IAM::Group | Amazon Web Services | iambic.plugins.v0_1_0.aws |
| NOQ::AWS::IAM::User | Amazon Web Service | iambic.plugins.v0_1_0.aws |
| NOQ::AzureAD::User | Azure Active Directory | iambic.plugins.v0_1_0.azure_ad |
| NOQ::AzureAD::Group | Azure Active Directory | iambic.plugins.v0_1_0.azure_ad |
| NOQ::GoogleWorkspace::Group | Google Workspace | iambic.plugins.v0_1_0.google_workspace |
| NOQ::GoogleWorkspace::User | Google Workspace | iambic.plugins.v0_1_0.google_workspace |
| NOQ::Okta::App | Okta | iambic.plugins.v0_1_0.okta |
| NOQ::Okta::Group | Okta | iambic.plugins.v0_1_0.okta |
| NOQ::Okta::User | Okta | iambic.plugins.v0_1_0.okta |
